EmailSniffer class
Matches email addresses. Example: example@domain.com
Constructors
- EmailSniffer({TextStyle? style, TextStyle? hoverStyle, RegExp? pattern})
-
Creates an email sniffer, optionally overriding the default
style,hoverStyleorpattern.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverStyle → TextStyle?
-
The style merged into style while the pointer hovers over a match
(web/desktop). When
null, matches have no hover effect.no setterinherited - pattern → RegExp?
-
The regular expression used to find matches. A
nullor empty pattern never matches.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
The style applied to text matched by this sniffer.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited