flutter_text_sniffer library
Classes
-
InlineSpanCache<
T> - RegexCache
- Cache for regular expressions to avoid creating new instances on each call.
-
TextSniffer<
T> - A widget that detects specific patterns within a text and makes them interactive.
Typedefs
-
MatchBuilder<
T> = Widget Function(String text, int index, SnifferType type, T? matchEntry) - A callback type for building custom widgets for matched text segments.
-
OnTapMatch<
T> = void Function(T? match, String matchText, SnifferType type, int index, Object? error) - A callback type for handling tap events on matched text segments.