Sniffer class abstract
An abstract class that defines the blueprint for text matching and styling.
This class is intended to be extended by specific implementations that provide regular expressions for matching text patterns and corresponding text styles for formatting the matched content.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverStyle → TextStyle?
-
The style merged into style while the pointer hovers over a match
(web/desktop). When
null, matches have no hover effect.no setter - pattern → RegExp?
-
The regular expression used to find matches. A
nullor empty pattern never matches.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
The style applied to text matched by this sniffer.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited